Welcome to PyAdaptiveCards's documentation!
===========================================

Adaptive Cards are a great way to extend your bot interactions. 
However, writing the JSON required to specify the card layout by hand can be cumbersome and 
error prone. And while using a designer is a good way to manually create cards this does not 
cover cards that are generated by code. PyAdaptiveCards allows you to author cards in native 
python without ever touching the underlying json. 

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   modules
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
